[Aboriginal] [PATCH] Replace FWL with ABL in the scripts

Alessio Igor Bogani alessiogirobogani at gmail.com
Fri Jun 17 03:24:31 PDT 2011


# HG changeset patch
# User Alessio Igor Bogani <alessiogirobogani at gmail.com>
# Date 1308306260 -7200
# Node ID e5cd1b9a5b4052f27204b39c168401675b778198
# Parent  02ada84fcbc518e206e576bea386a55630f02aac
Replace FWL with ABL in the scripts

diff -r 02ada84fcbc5 -r e5cd1b9a5b40 download.sh
--- a/download.sh	Fri Jun 17 12:15:34 2011 +0200
+++ b/download.sh	Fri Jun 17 12:24:20 2011 +0200
@@ -115,7 +115,7 @@
 # Create a MANIFEST file listing package versions.
 
 # This can optionally call source control systems (hg and svn) to get version
-# information for the FWL build scripts and any USE_UNSTABLE packages.  These
+# information for the ABL build scripts and any USE_UNSTABLE packages.  These
 # are intentionally excluded from the new path setup by host-tools.sh, so
 # just in case we've already run that use $OLDPATH for this.
 
diff -r 02ada84fcbc5 -r e5cd1b9a5b40 sources/functions.sh
--- a/sources/functions.sh	Fri Jun 17 12:15:34 2011 +0200
+++ b/sources/functions.sh	Fri Jun 17 12:24:20 2011 +0200
@@ -110,7 +110,7 @@
 {
   PREVIOUS=
   (cd "$STAGE_DIR" || dienow
-   find . -depth -newer "$CURSRC/FWL-TIMESTAMP" \
+   find . -depth -newer "$CURSRC/ABL-TIMESTAMP" \
      | sed -e 's/^.//' -e 's/^.//' -e '/^$/d'
   ) | while read i
   do
@@ -208,7 +208,7 @@
 
   if [ ! -z "$BINARY_PACKAGE_TARBALLS" ]
   then
-    touch "$CURSRC/FWL-TIMESTAMP" || dienow
+    touch "$CURSRC/ABL-TIMESTAMP" || dienow
     TIME=$(date +%s)
     while true
     do
@@ -281,16 +281,16 @@
 
 do_readme()
 {
   # Grab FWL version number
 
-  [ -z "$FWL_VERS" ] &&
-    FWL_VERS="mercurial rev $(cd "$TOP"; hg tip 2>/dev/null | sed -n 's/changeset: *\([0-9]*\).*/\1/p')"
+  [ -z "$ABL_VERS" ] &&
+    ABL_VERS="mercurial rev $(cd "$TOP"; hg tip 2>/dev/null | sed -n 's/changeset: *\([0-9]*\).*/\1/p')"
 
   cat << EOF
 Built on $(date +%F) from:
 
   Build script:
-    Aboriginal Linux (http://landley.net/aboriginal) $FWL_VERS
+    Aboriginal Linux (http://landley.net/aboriginal) $ABL_VERS
 
   Base packages:
     uClibc (http://uclibc.org) $(identify_release uClibc)
@@ -281,16 +281,16 @@
 do_readme()
 {
-  # Grab FWL version number
+  # Grab ABL version number
 



More information about the Aboriginal mailing list